@@ -1,8 +1,10 @@
-#include "typedefImport.h"
+#include "typedef.h"
 #include <wrap/ply/plylib.h>
 #include <vcg/container/simple_temporary_data.h>
 #include <wrap/io_trimesh/import.h>
 #include <vcg/complex/algorithms/pointcloud_normal.h>
+#include <wrap/io_trimesh/export_vrml.h>
+
 
 #include <string.h>
 #include "RvcgIO.h" 
@@ -13,7 +15,7 @@ using namespace Rcpp;
 RcppExport SEXP RMeshWrite(SEXP mesh_, SEXP binary_, SEXP addNormals_, SEXP filename_, SEXP colvec_, SEXP hasCol_, SEXP writeNormals_, SEXP type_)
 { 
   try {
-    MyMeshImport m;
+    MyMesh m;
     //set up parameters 
     List mesh(mesh_);
     bool binary = Rcpp::as<bool>(binary_);
@@ -29,7 +31,7 @@ RcppExport SEXP RMeshWrite(SEXP mesh_, SEXP binary_, SEXP addNormals_, SEXP file
     //allocate mesh and fill it
     Rcpp::IntegerMatrix colvec(colvec_);
     if (addNormals || writeNormals) {
-      m.vert.EnableNormal();
+      //m.vert.EnableNormal();
     }
     Rcpp::CharacterVector normname("normals");
     Rcpp::CharacterVector nam = mesh.names();
@@ -43,20 +45,20 @@ RcppExport SEXP RMeshWrite(SEXP mesh_, SEXP binary_, SEXP addNormals_, SEXP file
     if (!Rf_isMatrix(mesh["it"]))
       hasFaces = false;
   
-    Rvcg::IOMesh<MyMeshImport>::RvcgReadR(m,mesh["vb"],mesh["it"],mesh["normals"]);
+    Rvcg::IOMesh<MyMesh>::RvcgReadR(m,mesh["vb"],mesh["it"],mesh["normals"]);
     int mask0 = 0;
     
     if (addNormals) {
       if (hasFaces) {
-	tri::UpdateNormal<MyMeshImport>::PerVertexAngleWeighted(m);
+	tri::UpdateNormal<MyMesh>::PerVertexAngleWeighted(m);
       } else {
 	Rcpp::IntegerVector pointcloud= IntegerVector::create(10,0);
-	PointCloudNormal<MyMeshImport>::Param p;
+	PointCloudNormal<MyMesh>::Param p;
 	p.fittingAdjNum = pointcloud[0];
 	p.smoothingIterNum = pointcloud[1];
 	p.viewPoint = Point3f(0,0,0);
 	p.useViewPoint = false;
-	PointCloudNormal<MyMeshImport>::Compute(m,p);
+	PointCloudNormal<MyMesh>::Compute(m,p);
       }
     }
     if ( addNormals || writeNormals)
@@ -77,15 +79,15 @@ RcppExport SEXP RMeshWrite(SEXP mesh_, SEXP binary_, SEXP addNormals_, SEXP file
       }
     }
     if (type == 0)
-      tri::io::ExporterPLY<MyMeshImport>::Save(m, filename, mask0, binary);
+      tri::io::ExporterPLY<MyMesh>::Save(m, filename, mask0, binary);
     if (type == 1)
-      tri::io::ExporterOFF<MyMeshImport>::Save(m, filename, mask0);
+      tri::io::ExporterOFF<MyMesh>::Save(m, filename, mask0);
     if (type == 2)
-      tri::io::ExporterOBJ<MyMeshImport>::Save(m, filename, mask0);
+      tri::io::ExporterOBJ<MyMesh>::Save(m, filename, mask0);
     if (type == 3)
-      tri::io::ExporterSTL<MyMeshImport>::Save(m, filename, binary,mask0);
+      tri::io::ExporterSTL<MyMesh>::Save(m, filename, binary,mask0);
     if (type == 4)
-      tri::io::ExporterWRL<MyMeshImport>::Save(m, filename, mask0,0);
+      tri::io::ExporterWRL<MyMesh>::Save(m, filename, mask0,0);
     
     return Rcpp::wrap(0);
   } catch (std::exception& e) {
@@ -100,15 +102,15 @@ RcppExport SEXP RMeshWrite(SEXP mesh_, SEXP binary_, SEXP addNormals_, SEXP file
 // RcppExport SEXP RSTLWrite(SEXP vb_, SEXP it_, SEXP binary_, SEXP filename_)
 // { 
 // try {
-//   MyMeshImport m;
+//   MyMesh m;
 //   //set up parameters 
 //   bool binary = Rcpp::as<bool>(binary_);
 //   std::string str = Rcpp::as<std::string>(filename_);
 //   const char *filename = str.c_str();
 //   //allocate mesh and fill it
-//   Rvcg::IOMesh<MyMeshImport>::RvcgReadR(m,vb_,it_);
+//   Rvcg::IOMesh<MyMesh>::RvcgReadR(m,vb_,it_);
     
-//   tri::io::ExporterSTL<MyMeshImport>::Save(m, filename, binary);
+//   tri::io::ExporterSTL<MyMesh>::Save(m, filename, binary);
 //   return Rcpp::wrap(0);
 // } catch (std::exception& e) {
 //     ::Rf_error( e.what());
