@@ -85,15 +85,6 @@ static bool ReadHeader(FILE *fp,unsigned int &num_cams){
     return true;
 }
 
-static bool ReadHeader(const char * filename,unsigned int &/*num_cams*/, unsigned int &/*num_points*/){
-    FILE *fp = fopen(filename, "r");
-    if(!fp) return false;
-    ReadHeader(fp);
-    fclose(fp);
-    return true;
-}
-
-
 static int Open( OpenMeshType &m, std::vector<Shot<ScalarType> >  & shots,
                  std::vector<std::string > & image_filenames,
                  const char * filename, CallBackPos *cb=0)
@@ -154,7 +145,7 @@ static int Open( OpenMeshType &m, std::vector<Shot<ScalarType> >  & shots,
     shots[i].Intrinsics.FocalMm    = f/100.0f;
     shots[i].Intrinsics.k[0] = 0.0;//k1; To be uncommented when distortion is taken into account reliably
     shots[i].Intrinsics.k[1] = 0.0;//k2;
-    shots[i].Intrinsics.PixelSizeMm = vcg::Point2<ScalarType>(0.01,0.01);
+    shots[i].Intrinsics.PixelSizeMm = vcg::Point2<ScalarType>(ScalarType(0.01), ScalarType(0.01));
     QImageReader sizeImg(QString::fromStdString(image_filenames[i]));
     QSize size=sizeImg.size();
     shots[i].Intrinsics.ViewportPx = vcg::Point2i(size.width(),size.height());
